# AWS Pricing API
This repository contains the package the uses the AWS Pricing API for estimating AWS Resources.

## Requirements
- Python 3.6 or higher
- boto3


#### Installation

```
# install via pip
```


#### Original Author

```
Name    : Adamson dela Cruz
Email   : adamson.delacruz@gmail.com

```
